# PerfTrackerGT

Welcome to PerfTrackerGT! This application is designed to help you track and analyze the performance of your functions in your software projects. Whether you're a developer, project manager, or team lead, PerfTrackerGT provides valuable insights into your project's performance metrics.

## Features

- Time measurement: Measure the time it takes your function to complete
- Memory Consumption: Measures how much memory does your function require at it's initial state and when it's completed.

## Getting Started

To get started with PerfTrackerGT, follow these steps:

1. Type on your terminal `pip install perftrackergt`.

## Contributing

Ask in the discord channel (Hablamos espanol btw)

## License

This project is licensed under the [MIT License](https://github.com/your-username/PerfTrackerGT/blob/main/LICENSE).
